#!/usr/bin/env python

from __future__ import division
from pyrk import RK4
from math import sin, pi, cos
# import numpy as np
# import matplotlib.pyplot as plt


def test_solve():
	rk = RK4(lambda t, y, u: cos(t))
	y = 0.0
	t, y = rk.solve(y, 0.01, 2.0*pi)
	# print(y)
	# print(y[-1])
	# plt.plot(t, y)
	# plt.show()
	assert(y[-1] < 0.01)

def test_step():
	rk = RK4(lambda t, y, u: cos(t))
	y = 0.0
	t = 0.0
	step = 0.01

	while t <= 2.0*pi:
		y = rk.step(y, None, t, step)
		t += step

	# print(y)
	assert(y < 0.01)


# test_solve()
test_step()



# import os
from setuptools import setup
from setuptools import find_packages

setup(
	name='pyrk',
	version='0.5.1',
	description="A simple runge-kutta 4 integrator",
	long_description=open('README.rst').read(),
	author="Kevin Walchko",
	author_email='kevin.walchko@outlook.com',
	# platforms=["any"],  # or more specific, e.g. "win32", "cygwin", "osx"
	license="MIT",
	url="http://github.com/walchko/pyrk",
	# zip_safe=False,
	# packages=find_packages(exclude=['examples', 'test', 'doc']),  # doesn't work
	packages=find_packages('pyrk'),
	package_dir={'':'pyrk'},
	# packages=['pyrk'],
	keywords='ode integration rk4 rk runge kutta',
	classifiers=[
		'Development Status :: 4 - Beta',
		'Intended Audience :: Science/Research',
		'Operating System :: OS Independent',
		'License :: OSI Approved :: MIT License',
		'Intended Audience :: Developers',
		'Programming Language :: Python :: 2.7',
		'Programming Language :: Python :: 2 :: Only',
		'Topic :: Scientific/Engineering',
		'Topic :: Software Development'
	]
)
